@@ -52,7 +52,7 @@ pub trait CSharpTypeConverter {
             CType::Pattern(p) => match p {
                 TypePattern::AsciiPointer => "string".to_string(),
                 TypePattern::NamedCallback(x) => x.name().to_string(),
-                TypePattern::SuccessEnum(e) => self.enum_to_typename(e.the_enum()),
+                TypePattern::FFIErrorEnum(e) => self.enum_to_typename(e.the_enum()),
                 TypePattern::Slice(p) => {
                     let element_type = p
                         .fields()
@@ -76,7 +76,7 @@ pub trait CSharpTypeConverter {
                 }
 
                 TypePattern::Option(e) => self.composite_to_typename(e),
-                TypePattern::Bool => "FFIBool".to_string(),
+                TypePattern::Bool => "Bool".to_string(),
                 TypePattern::APIVersion => self.to_typespecifier_in_param(&p.fallback_type()),
             },
             x => self.to_typespecifier_in_param(x),
@@ -110,12 +110,12 @@ pub trait CSharpTypeConverter {
             CType::FnPointer(x) => self.fnpointer_to_typename(x),
             CType::Pattern(x) => match x {
                 TypePattern::AsciiPointer => "string".to_string(),
-                TypePattern::SuccessEnum(e) => self.enum_to_typename(e.the_enum()),
+                TypePattern::FFIErrorEnum(e) => self.enum_to_typename(e.the_enum()),
                 TypePattern::Slice(e) => self.composite_to_typename(e),
                 TypePattern::SliceMut(e) => self.composite_to_typename(e),
                 TypePattern::Option(e) => self.composite_to_typename(e),
                 TypePattern::NamedCallback(e) => self.named_callback_to_typename(e),
-                TypePattern::Bool => "FFIBool".to_string(),
+                TypePattern::Bool => "Bool".to_string(),
                 TypePattern::APIVersion => self.to_typespecifier_in_field(&x.fallback_type(), field, composite),
             },
         }
@@ -146,12 +146,12 @@ pub trait CSharpTypeConverter {
             CType::FnPointer(x) => self.fnpointer_to_typename(x),
             CType::Pattern(x) => match x {
                 TypePattern::AsciiPointer => "string".to_string(),
-                TypePattern::SuccessEnum(e) => self.enum_to_typename(e.the_enum()),
+                TypePattern::FFIErrorEnum(e) => self.enum_to_typename(e.the_enum()),
                 TypePattern::Slice(x) => self.composite_to_typename(x),
                 TypePattern::SliceMut(x) => self.composite_to_typename(x),
                 TypePattern::Option(x) => self.composite_to_typename(x),
                 TypePattern::NamedCallback(x) => self.named_callback_to_typename(x),
-                TypePattern::Bool => "FFIBool".to_string(),
+                TypePattern::Bool => "Bool".to_string(),
                 TypePattern::APIVersion => self.to_typespecifier_in_param(&x.fallback_type()),
             },
         }
@@ -169,12 +169,12 @@ pub trait CSharpTypeConverter {
             CType::FnPointer(x) => self.fnpointer_to_typename(x),
             CType::Pattern(x) => match x {
                 TypePattern::AsciiPointer => "string".to_string(),
-                TypePattern::SuccessEnum(e) => self.enum_to_typename(e.the_enum()),
+                TypePattern::FFIErrorEnum(e) => self.enum_to_typename(e.the_enum()),
                 TypePattern::Slice(x) => self.composite_to_typename(x),
                 TypePattern::SliceMut(x) => self.composite_to_typename(x),
                 TypePattern::Option(x) => self.composite_to_typename(x),
                 TypePattern::NamedCallback(x) => self.named_callback_to_typename(x),
-                TypePattern::Bool => "FFIBool".to_string(),
+                TypePattern::Bool => "Bool".to_string(),
                 TypePattern::APIVersion => self.to_typespecifier_in_rval(&x.fallback_type()),
             },
         }
